<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Atd
 * @subpackage Atd/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Atd
 * @subpackage Atd/public
 * @author     ORION <support@orionorigin.com>
 */
class Atd_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Atd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Atd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/atd-public.css', array(), $this->version, 'all');
        wp_enqueue_style('atd-modal-css', ATD_URL . 'includes/skins/default/assets/css/modal.min.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Atd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Atd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/atd-public.js', array('jquery'), $this->version, false);
        wp_localize_script($this->plugin_name, 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
        wp_enqueue_script('atd-modal-js', ATD_URL . 'includes/skins/default/assets/js/modal/modal.min.js', array(), $this->version, false);
    }

    /**
     * Get start designing button.
     */
    public function get_start_designing_btn() {
        $product_id = get_the_ID();
        $atd_product = new ATD_Product($product_id);
        echo $atd_product->get_buttons(true);
    }

    /**
     * Add query variables.
     *
     * @param type $a_vars the array variables.
     * @return array.
     */
    public function atd_add_query_vars($a_vars) {
        $a_vars[] = 'product_id';
        $a_vars[] = 'tpl';
        $a_vars[] = 'edit';
        $a_vars[] = 'design_index';
        $a_vars[] = 'oid';
        return $a_vars;
    }

    /**
     * Rewrite rules.
     *
     * @global type $atd_settings the setting.
     * @global type $wp_rewrite the WordPress rewrite.
     * @param type $param the parameter.
     */
    public function atd_add_rewrite_rules($param) {
        global $atd_settings;
        global $wp_rewrite;
        $options = $atd_settings['atd-general-options'];
        $atd_page_id = $options['atd_page_id'];
        if (function_exists('icl_object_id')) {
            $atd_page_id = icl_object_id($atd_page_id, 'page', false, ICL_LANGUAGE_CODE);
        }
        $atd_page = get_post($atd_page_id);
        if (is_object($atd_page)) {
            $raw_slug = get_permalink($atd_page->ID);
            $home_url = home_url('/');
            $slug = str_replace($home_url, '', $raw_slug);
            // If the slug does not have the trailing slash, we get 404 (ex postname = /%postname%).
            $sep = '';
            if ('/' !== substr($slug, -1)) {
                $sep = '/';
            }
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'design' . '/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&tpl=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'edit' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&edit=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'ordered-design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&oid=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );

            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'saved-design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&design_index=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            $wp_rewrite->flush_rules(false);
        }
    }

    /**
     * Set variable action filters.
     *
     * @global type $atd_settings the settings.
     */
    public function set_variable_action_filters() {
        $woo_version = $this->atd_get_woo_version_number();
        if ($woo_version < 2.1) {
            // Old WC versions
            add_filter('woocommerce_in_cart_product_title', array($this, 'get_atd_data'), 10, 3);
        } else {
            // New WC versions
            add_filter('woocommerce_cart_item_name', array($this, 'get_atd_data'), 10, 3);
        }
        add_filter('the_content', array($this, 'filter_content'), 99);
    }

    /**
     * Get item class.
     *
     * @global type $atd_settings The settings.
     * @param type $classes The classes.
     * @param type $class The class.
     * @param type $post_id The post id.
     * @return type
     */
    public function get_item_class($classes, $class, $post_id) {
        global $atd_settings;
        $general_options = $atd_settings['atd-general-options'];
        $hide_cart_button = get_proper_value($general_options, 'atd-hide-cart-button', true);

        if (in_array('product', $classes, true)) {
            $atd_product = new ATD_Product($post_id);
            if ($atd_product->is_customizable()) {
                array_push($classes, 'atd-is-customizable');
            }
            if ($hide_cart_button) {
                array_push($classes, 'atd-hide-cart-button');
            }
        }
        return $classes;
    }

    /**
     * Register the plugin shortcodes
     */
    public function register_shortcodes() {
        add_shortcode('atd-editor', array($this, 'get_editor_shortcode_handler'));
    }

    /**
     * Get editor shortcode handler.
     *
     * @global type $wp_query the WordPress query.
     * @return type object.
     */
    public function get_editor_shortcode_handler() {
        global $wp_query;
        if (!isset($wp_query->query_vars['product_id'])) {
            return __("You're trying to access the customization page whitout a product to customize. This page should only be accessed using one of the customization buttons.", 'atd');
        }

        $item_id = $wp_query->query_vars['product_id'];
        $editor_obj = new ATD_Editor($item_id);
        return $editor_obj->get_editor();
    }

    /**
     * Get the woocommerce version number.
     * 
     * @return int Sversion The version.
     */
    private function atd_get_woo_version_number() {
        // If get_plugins() isn't available, require it
        if (!function_exists('get_plugins')) {
            require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }

        // Create the plugins folder and file variables
        $plugin_folder = get_plugins('/' . 'woocommerce');
        $plugin_file = 'woocommerce.php';

        // If the plugin version number is set, return it
        if (isset($plugin_folder[$plugin_file]['Version'])) {
            return $plugin_folder[$plugin_file]['Version'];
        } else {
            // Otherwise return null
            return null;
        }
    }

    /**
     * Filter content.
     *
     * @global type $atd_settings the settings.
     * @global type $wp_query the WordPress query.
     * @param type $content the content.
     * @return type
     */
    public function filter_content($content) {
        global $atd_settings, $wp_query;

        $options = $atd_settings['atd-general-options'];
        $atd_page_id = $options['atd_page_id'];
        if (function_exists('icl_object_id')) {
            $atd_page_id = icl_object_id($atd_page_id, 'page', false, ICL_LANGUAGE_CODE);
        }
        $current_page_id = get_the_ID();
        if (!is_admin() && $atd_page_id == $current_page_id && isset($wp_query->query_vars['product_id']) && !empty($wp_query->query_vars['product_id'])) {
            $editor_obj = new ATD_Editor($wp_query->query_vars['product_id']);
            $content .= $editor_obj->get_editor();
        }
        return $content;
    }

    /**
     * Get ATD data.
     * 
     * @param type $thumbnail_code The thumbnail code.
     * @param type $values The values.
     * @param type $cart_item_key The cart item key.
     */
    public function get_atd_data($thumbnail_code, $values, $cart_item_key) {
        $variation_id = $values['variation_id'];
        if (isset($values['atd_design_pricing_options']) && !empty($values['atd_design_pricing_options'])) {
            $atd_design_pricing_options_data = ATD_Design::get_design_pricing_options_data($values['atd_design_pricing_options']);
            $thumbnail_code .= '<br>' . $atd_design_pricing_options_data;
        }

        if (isset($values['atd_generated_data']) && isset($values['atd_generated_data']['output'])) {
            $thumbnail_code .= '<br>';
            $customization_list = $values['atd_generated_data'];
            $modals = '';
            if (class_exists('Ofb')) {
                if (isset($customization_list['output']['form_fields'])) {
                    $form_fields = $customization_list['output']['form_fields'];
                    foreach ($form_fields as $key => $value) {
                        if (!is_array($value)) {
                            $thumbnail_code .= '<p>' . $key . ' : ' . $value . '</p>';
                        } else {
                            $thumbnail_code .= '<p>' . $key . ' : ';
                            foreach ($value as $data) {
                                $thumbnail_code .= $data . ' ';
                            }
                            $thumbnail_code .= ' </p>';
                        }
                    }
                }
            }
            $i = 0;
            foreach ($customization_list['output']['files'] as $customisation_key => $customization) {
                $tmp_dir = $customization_list['output']['working_dir'];
                $generation_url = ATD_ORDER_UPLOAD_URL . "/$tmp_dir/$customisation_key/";
                if (isset($customization['preview'])) {
                    $image = $generation_url . $customization['preview'];
                } else {
                    $image = $generation_url . $customization['image'];
                }
                $original_part_img_url = $customization_list[$customisation_key]['original_part_img'];
                $modal_id = $variation_id . '_' . $cart_item_key . "$customisation_key-$i";

                $thumbnail_code .= '<span><a class="button" data-part-name="' . $customisation_key . '" data-variation-id="' . $variation_id . '" data-toggle="o-modal" data-target="#' . $modal_id . '">' . ucfirst($customisation_key) . '</a></span>';
                $modals .= '<div class="omodal fade atd-modal atd_part" id="' . $modal_id . '" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                                    <div class="omodal-dialog">
                                      <div class="omodal-content">
                                        <div class="omodal-header">
                                          <button type="button" class="close" data-dismiss="omodal" aria-hidden="true">&times;</button>
                                          <h4 class="omodal-title">' . __('Preview', 'atd') . '</h4>
                                        </div>
                                        <div class="omodal-body txt-center">
                                            <div style="background-image:url(' . $original_part_img_url . ')"><img src="' . $image . '"></div>
                                        </div>
                                      </div>
                                    </div>
                                  </div>';
                $i++;
            }
            array_push(atd_retarded_actions::$code, $modals);
            add_action('wp_footer', array('atd_retarded_actions', 'display_code'), 10, 1);

            $atd_product = new ATD_Product($variation_id);
            $edit_item_url = $atd_product->get_design_url(false, $cart_item_key, false, false, true);
            $thumbnail_code .= '<a class="button alt" href="' . $edit_item_url . '">' . __('Edit', 'atd') . '</a>';
        } elseif (isset($values['atd-uploaded-designs'])) {
            $thumbnail_code .= '<br>';
            foreach ($values['atd-uploaded-designs'] as $custom_design) {
                $thumbnail_code .= '<span class="atd-custom-design"><a class="button" href=' . $custom_design . '>' . __('Custom design', 'atd') . '</a></span>';
            }
        }
        echo $thumbnail_code;
    }

    /**
     * Initialize the plugin sessions
     */
    function init_sessions() {
        if (!session_id()) {
            session_start();
        }
        if (!isset($_SESSION['atd-data-to-load'])) {
            $_SESSION['atd-data-to-load'] = '';
        }
        $_SESSION['atd_calculated_totals'] = false;
    }

    /**
     * Handle picture upload.
     */
    public function handle_picture_upload() {
        if (!check_ajax_referer('atd-picture-upload-nonce', 'nonce', false)) {
            $busted = __('Cheating huh?', 'atd');
            die(esc_html($busted));
        }

        $generation_path = ATD_TMP_UPLOAD_PATH;
        if (!is_dir($generation_path)) {
            wp_mkdir_p($generation_path);
        }
        $generation_url = ATD_TMP_UPLOAD_URL;
        $file_name = uniqid();
        $options = get_option('atd-upload-options');
        $valid_formats = $options['atd-upl-extensions'];
        if (!$valid_formats) {
            $valid_formats = array('jpg', 'jpeg', 'png', 'gif', 'bmp', 'svg');
        }
        $name = $_FILES['userfile']['name'];
        //$size = $_FILES['userfile']['size'];
        if (isset($_POST) and $_SERVER['REQUEST_METHOD'] == 'POST') {
            if (strlen($name)) {
                $success = 0;
                $message = '';
                $img_url = '';
                $img_id = uniqid();
                $path_parts = pathinfo($name);
                $ext = strtolower($path_parts['extension']);
                if (in_array($ext, $valid_formats)) {
                    $tmp = $_FILES['userfile']['tmp_name'];
                    if (move_uploaded_file($tmp, $generation_path . '/' . $file_name . ".$ext")) {
                        $min_width = $options['atd-min-upload-width'];
                        $min_height = $options['atd-min-upload-height'];
                        $valid_formats_for_thumb = array('psd', 'eps', 'pdf');
                        if ($min_width > 0 || $min_height > 0) {
                            list($width, $height, $type, $attr) = getimagesize($generation_path . '/' . $file_name . ".$ext");
                            if (( $min_width > $width || $min_height > $height ) && $ext != 'svg') {
                                $success = 0;
                                $message = sprintf(__('Uploaded file dimensions: %1$spx x %2$spx, minimum required ', 'atd'), $width, $height);
                                if ($min_width > 0 && $min_height > 0) {
                                    $message .= __('dimensions:', 'atd') . " $min_height" . 'px' . " x $min_height" . 'px';
                                } elseif ($min_width > 0) {
                                    $message .= "width: $min_width" . 'px';
                                } elseif ($min_height > 0) {
                                    $message .= "height: $min_height" . 'px';
                                }
                            } else {
                                $success = 1;
                                
                                $message = "<div class='atd-preview-upolad-item atd-fade' data-title='" . $file_name . "' data-upload-id='" . $img_id . "' data-url='" . $generation_url . "/" . $file_name . "." . $ext . "' data-img-name='" . $file_name . "'><div class='atd-preview-upolad' style='background-image:url(" . $generation_url . "/" . $file_name . "." . $ext . ")'></div><div class='atd-icon-cross'><i class='fas fa-times'></i></div></div>";
                                $img_url = "$generation_url/$file_name.$ext";
                            }
                        } else {
                            $success = 1;
                            $message = "<div class='atd-preview-upolad-item atd-fade' data-title='" . $file_name . "' data-upload-id='" . $img_id . "' data-url='" . $generation_url . "/" . $file_name . "." . $ext . "' data-img-name='" . $file_name . "'><div class='atd-preview-upolad' style='background-image:url(" . $generation_url . "/" . $file_name . "." . $ext . ")'></div><div class='atd-icon-cross'><i class='fas fa-times'></i></div></div>";
                            $img_url = "$generation_url/$file_name.$ext";
                        }
                        if ($success == 0) {
                            unlink($generation_path . '/' . $file_name . ".$ext");
                        }
                    } else {
                        $success = 0;
                        $message = __('An error occured during the upload. Please try again later', 'atd');
                    }
                } else {
                    $success = 0;
                    $message = __('Incorrect file extension: ' . $ext . '. Allowed extensions: ', 'atd') . implode(', ', $valid_formats);
                }

                if ($success === 1) {
                    $new_atd_upload = array(
                        'img_url' => $img_url,
                        'img_id' => $img_id,
                        'img_name' => $name = $_FILES['userfile']['name'],
                    );
                    if (!is_user_logged_in()) {
                        if (isset($_COOKIE['atd-upload']) && !empty($_COOKIE['atd-upload'])) {
                            $atd_upload_json = json_decode(base64_decode($_COOKIE['atd-upload']));
                            if (null === $atd_upload_json) {
                                $atd_upload = array();
                            } else {
                                $atd_upload = $atd_upload_json;
                            }
                        } else {
                            $atd_upload = array();
                        }
                        array_push($atd_upload, $new_atd_upload);
                        $atd_upload_json = base64_encode(json_encode($atd_upload));
                        setcookie('atd-upload', $atd_upload_json, time() + 365 * 24 * 3600, '/');
                    } else {
                        global $current_user;
                        $current_user_id = $current_user->ID;
                        $user_uploads = get_user_meta($current_user_id, 'atd_saved_uploads');
                        if (empty($user_uploads)) {
                            $user_uploads = array();
                        } else {
                            $user_uploads = $user_uploads[0];
                        }
                        $user_uploads[] = $new_atd_upload;
                        update_user_meta($current_user_id, 'atd_saved_uploads', $user_uploads);
                    }
                }
                echo json_encode(
                        array(
                            'success' => $success,
                            'message' => $message,
                            'img_url' => $img_url,
                            'img_id' => $img_id,
                        )
                );
            }
        }
        die();
    }
    
    /**
     * Handle delete picture upload.
     * 
     * @global type $current_user
     */
    public function handle_delete_picture_upload() {
        $success = 0;
        $element_key = '';
        $img_id = filter_input(INPUT_POST, 'img_id');
        $img_url = filter_input(INPUT_POST, 'img_url');
        $img_name = filter_input(INPUT_POST, 'img_name');
        if (!is_user_logged_in()) {
            if (isset($_COOKIE['atd-upload']) && !empty($_COOKIE['atd-upload'])) {
                $atd_upload_json = json_decode(base64_decode($_COOKIE['atd-upload']));
                if (null === $atd_upload_json) {
                    $atd_upload = array();
                } else {
                    $atd_upload = $atd_upload_json;
                }
            } else {
                $atd_upload = array();
            }
            if (is_array($atd_upload) && !empty($atd_upload)) {
                foreach ($atd_upload as $key => $value) {
                    if ($value->img_id == $img_id && $value->img_name == $img_name && $value->img_url == $img_url) {
                        $element_key = $key;
                        break;
                    }
                }
            }
            if (!empty($element_key) || 0 === $element_key) {
                unset($atd_upload[$element_key]);
                //array_splice( $atd_upload, $element_key );
                $atd_upload_json = base64_encode(json_encode($atd_upload));
                setcookie('atd-upload', $atd_upload_json, time() + 365 * 24 * 3600, '/');
                $success = 1;
            } else {
                $success = 0;
            }
        } else {
            global $current_user;
            $current_user_id = $current_user->ID;
            $user_uploads = get_user_meta($current_user_id, 'atd_saved_uploads');
            if (empty($user_uploads)) {
                $user_uploads = array();
            } else {
                $user_uploads = $user_uploads[0];
            }
            if (is_array($user_uploads) && !empty($user_uploads)) {
                foreach ($user_uploads as $key => $value) {
                    if ($value['img_id'] == $img_id && $value['img_name'] == $img_name && $value['img_url'] == $img_url) {
                        $element_key = $key;
                        break;
                    }
                }
            }
            if (!empty($element_key) || 0 === $element_key) {
                unset($user_uploads[$element_key]);
                //array_splice( $user_uploads, $element_key );
                update_user_meta($current_user_id, 'atd_saved_uploads', $user_uploads);
                $success = 1;
            } else {
                $success = 0;
            }
        }
        echo json_encode($success);
        die();
    }

    /**
     * Move user picture uploads.
     *
     * @param type $user_id The user id.
     */
    public function move_user_picture_uplaods($user_id) {
        $user_uploads = array();
        if (isset($_COOKIE['atd-upload']) && !empty($_COOKIE['atd-upload'])) {
            $atd_upload_json = json_decode(base64_decode($_COOKIE['atd-upload']));
            if (null === $atd_upload_json) {
                $atd_upload = array();
            } else {
                $atd_upload = $atd_upload_json;
            }
        } else {
            $atd_upload = array();
        }
        foreach ($atd_upload as $image) {
            $user_upload = array();
            if (isset($image->img_id) && !empty($image->img_id)) {
                $user_upload['img_id'] = $image->img_id;
            }
            if (isset($image->img_url) && !empty($image->img_url)) {
                $user_upload['img_url'] = $image->img_url;
            }
            if (isset($image->img_name) && !empty($image->img_name)) {
                $user_upload['img_name'] = $image->img_name;
            }

            array_push($user_uploads, $user_upload);
        }
        add_user_meta($user_id, 'atd_saved_uploads', $user_uploads);
    }
    
     /**
     * Store variation attributes.
     */
    public function atd_store_variation_attributes() {
        $variations = $data['data'];
        $transient = uniqid('atd-');
        set_transient($transient, $variations, HOUR_IN_SECONDS);
        $_SESSION['atd_key'] = $transient;
        die();
    }

    /**
     * Get and send custom product by ajax
     */
    public function display_related_custom_products(){
        if(isset($_POST["product_id"]))
        {
            $dflt_variation_id=intval($_POST["variation_id"]);
            $product_id = intval($_POST["product_id"]);
            $result_data = atd_get_related_custom_product();

            $active_product_meta_value = get_post_meta( $product_id, 'atd-metas', true );
            $active_product_first_key = array_key_first($active_product_meta_value);
            $dflt_image_link= $this->get_variation_image_link($dflt_variation_id);
                            
            ?>
                <div class="atd-preview-box-add-cart-card" data-id="<?= $product_id ?>">

                    <div class="atd-preview-box-add-cart-img-inner">

                        <img src="<?php if(empty($dflt_image_link)){echo wc_placeholder_img_src();}else{ echo $dflt_image_link;} ?>" class="atd-preview-box-add-cart-img" alt="<?= __(get_the_title($product_id), "atd") ?>">

                    </div>

                    <div class="atd-preview-box-add-cart-card-body">

                    <h4 class="atd-cart-product-title"><?= __(get_the_title($product_id), "atd") ?></h4>

                        <button type="button" class="atd-btn-cart-modal"><?= __("Add another colors", "atd")?></button>

                    </div>

                </div>
            <?php

            foreach ($result_data["data"] as $key => $value){
                
                $product_data = wc_get_product($value->ID);
                
                if($product_data->is_in_stock() && $product_data->get_type()=="variable")
                {
                    $related_custom_product_details=atd_get_related_custom_product_details($value->ID);
                    if($related_custom_product_details)
                    {
                        $first_variation_key=array_key_first($related_custom_product_details["variation_id"]);
                        $first_variation_id=$related_custom_product_details["variation_id"][$first_variation_key];
                        $first_variation_image=$this->get_variation_image_link($first_variation_id);
                        $meta_value = get_post_meta($value->ID, 'atd-metas', true);
                        if(!empty($meta_value) && is_array($meta_value))
                        {
                            $active_config=$active_product_meta_value[$active_product_first_key]["config-id"];
                                
                            if($this->atd_verif_if_as_active_configuration($meta_value, $active_config) && intval($value->ID)!==$product_id)
                            {
                                    
                                $image_link= wp_get_attachment_image_src(get_post_thumbnail_id(intval($value->ID)), 'thumbnail');
                                    
                                ?>
                                    <div class="atd-preview-box-add-cart-card" data-id="<?php echo $value->ID; ?>">

                                        <div class="atd-preview-box-add-cart-img-inner">

                                            <img src="
                                            <?php
                                                if(!empty($first_variation_image))
                                                {
                                                    echo $first_variation_image;
                                                }
                                                elseif(!empty($image_link))
                                                {
                                                    echo $image_link[0];
                                                }
                                                else
                                                    echo wc_placeholder_img_src();

                                            ?>
                                            " class="atd-preview-box-add-cart-img" alt="<?= __(get_the_title($value->ID), "atd") ?>">
                                        </div>

                                        <div class="atd-preview-box-add-cart-card-body">

                                            <h4 class="atd-cart-product-title"><?= __(get_the_title($value->ID), "atd") ?></h4>

                                            <button type="button" class="atd-btn-cart-modal"><?= __("Add this product", "atd")?></button>

                                        </div>

                                    </div>
                                 <?php
                            }
                        }
                    }
                    
                }
            }
            die();
        }
    }


    /**
     * Check if configuration is define
     */
    public function atd_verif_if_as_active_configuration(array $meta, $config_id)
    {
        foreach($meta as $key => $value)
        {
            if($value["config-id"]!="" && $config_id==$value["config-id"])
                return true;
        }
        
        return false;
    }

    /**
     * Get and send custom product details by ajax
     */

    public function display_related_custom_product_details(){
        if(isset($_POST["product_id"])){

            $product_id=$_POST["product_id"];

            $dflt_product_id= $_POST["dflt_product_id"];
            $dflt_variation_id= $_POST["dflt_variation_id"];
            $related_custom_product_details=atd_get_related_custom_product_details($product_id);
            $dflt_image_link= $this->get_variation_image_link($dflt_variation_id);

            $selected_attr = atd_get_variation_attr_name($product_id);
            $attribute= wc_get_product_variation_attributes($dflt_variation_id);
            $variation_color=$attribute["attribute_".$selected_attr["color"]];
            $variation_size=$attribute["attribute_".$selected_attr["size"]];
            
            $first_variation_key=array_key_first($related_custom_product_details["variation_id"]);
            $first_variation_id=$related_custom_product_details["variation_id"][$first_variation_key];
            $first_variation_image=$this->get_variation_image_link($first_variation_id);

            $first_variation_attribute= wc_get_product_variation_attributes($first_variation_id);
            $first_variation_variation_color=$first_variation_attribute["attribute_".$selected_attr["color"]];
            $first_variation_variation_size=$first_variation_attribute["attribute_".$selected_attr["size"]];

            if($dflt_product_id==$product_id)
            {
                $default=true;
            }
            if(is_array($related_custom_product_details))
            {
                $compt=0;
                $meta_value=get_post_meta($product_id, 'atd-metas', true);
                $image_link= wp_get_attachment_image_src(get_post_thumbnail_id(intval($product_id)), 'thumbnail');
                $global_variation_data=array(
                    "product_id"        =>  $product_id,
                    "product_title"     =>  get_the_title($product_id),
                    "variation_id"      =>  $related_custom_product_details["variation_id"],
                    "variation_sizes"   =>  $related_custom_product_details["variation_sizes"],
                    "variation_color"   =>  $related_custom_product_details["variation_color"],
                    "variation_combinaison" => $related_custom_product_details["variation_combinaison"]
                );

                ?> 
                
                    <div class="atd-modal-product-details">
                        <div class="atd-preview-box-add-cart-img-inner">
                            <?php
                                if($default)
                                {
                                    ?>
                                        <img src="<?php if(empty($dflt_image_link)){echo wc_placeholder_img_src();}else{ echo $dflt_image_link;} ?>" alt="<?php echo get_the_title($product_id); ?>" class="atd-preview-box-add-cart-img">
                                    <?php
                                    $image_link=$dflt_image_link;
                                }
                                else{
                                    ?>
                                        <img src="<?php if(empty($first_variation_image)){echo wc_placeholder_img_src();}else{ echo $first_variation_image;} ?>" alt="<?php echo get_the_title($product_id); ?>" class="atd-preview-box-add-cart-img">
                                    <?php
                                }
                              
                            ?>
                        </div>
                        <h4 class="atd-cart-product-details-title"><?= __(get_the_title($product_id), 'atd') ?></h4>

                        <p class="atd-cart-product-details-desc">
                            <?= __($related_custom_product_details["short_description"], 'atd') ?>
                        </p>

                    </div>


                    <div class="atd-modal-product-details">

                        <h3 class="atd-product-question-text"><?= __('What color product would you like to add?', 'atd') ?></h3>

                        <div class="atd-product-question-color-text">

                            <span class="atd-product-select-color"><?= __('Selected color:&nbsp;', 'atd') ?></span>

                            <div class="atd-img-swatch ">
                                <?php
                                    if($default)
                                    {
                                        ?>
                                            <img src="<?php if(empty($dflt_image_link)){echo wc_placeholder_img_src();}else{ echo $dflt_image_link;} ?>" alt="<?php echo get_the_title($product_id); ?>" class="atd-preview-box-add-cart-img" data-src="<?php if(empty($dflt_image_link)){echo wc_placeholder_img_src();}else{ echo $dflt_image_link;} ?>">
                                        <?php
                                    }
                                    else
                                    {
                                        ?>
                                            <img src="<?php if(empty($first_variation_image)){echo wc_placeholder_img_src();}else{ echo $first_variation_image;} ?>" alt="<?php echo get_the_title($product_id); ?>" class="atd-preview-box-add-cart-img" data-src="<?php if(empty($first_variation_image)){echo wc_placeholder_img_src();}else{ echo $first_variation_image;} ?>">
                                        <?php
                                    }
                                ?>
                            </div>
                           
                            <span class="atd-product-variation-text" old-color="<?php if($default){echo __($variation_color, 'atd');}else{echo __($first_variation_variation_color, 'atd');} ?>" data-name="<?= get_the_title($product_id) ?>" product-data-id="<?= $product_id?>"><?php if($default){echo __($variation_color, 'atd');}else{echo __($first_variation_variation_color, 'atd');} ?></span>
                        </div>
                        <script type="text/javascript">
                                var global_variation_data=<?php echo json_encode($global_variation_data); ?> ;
                            </script>
                        <div class="atd-color-choices">
                            
                            <?php
                                    $part_data_bg=$this->get_part_image($dflt_product_id, $dflt_variation_id, "bg-inc");

                                    $part_data_icon=$this->get_part_image($dflt_product_id, $dflt_variation_id, "icon");

                                    $used_color_temp=[];

                                    if($default)
                                    {
                                        array_push($used_color_temp, $variation_color);

                                        if(empty($dflt_image_link))
                                        {
                                            ?>
                                                <div class="atd-color-choice-item" atd-variation-id="<?= $dflt_variation_id ?>" data-title="<?= $variation_color ?>" >
                                                    <img src="<?= wc_placeholder_img_src() ?>" alt="<?= __(get_the_title($dflt_product_id), 'atd') ?>" class="atd-preview-box-add-cart-img" data-src="<?= wc_placeholder_img_src() ?>" data-id="<?= $dflt_variation_id ?>">
                                                </div>
                                            <?php
                                        }
                                        else{
                                            ?>
                                                <div class="atd-color-choice-item" atd-variation-id="<?= $dflt_variation_id ?>" data-title="<?= $variation_color ?>">
                                                    <img src="<?= $dflt_image_link ?>" alt="<?= __(get_the_title($dflt_product_id), 'atd') ?>" class="atd-preview-box-add-cart-img" data-src="<?= $dflt_image_link ?>" data-id="<?= $dflt_variation_id ?>" >
                                                </div>
                                            <?php
                                        }
                                    }
                                    
                                    
                                    

                                    foreach ($part_data_bg as $xkey => $img_url){
                                        ?>
                                            <span atd-variation-id="<?= $dflt_variation_id ?>" data-title="<?= $xkey."_".$dflt_variation_id ?>" style="display:none;">
                                                <img src="<?= o_get_proper_image_url($img_url) ?>">
                                            </span>
                                        <?php
                                    } 
                                    
                                    foreach ($part_data_icon as $xkey => $img_url){
                                        ?>
                                            <span atd-variation-id="<?= $value ?>" data-title="<?= "icon_".$xkey."_".$value ?>" style="display:none;">
                                                <img src="<?= o_get_proper_image_url($img_url) ?>">
                                            </span>
                                        <?php
                                    }

                                    foreach ($related_custom_product_details["variation_id"] as $key => $value){
                                        $image_url= $this->get_variation_image_link($value);
                                        $attribute= wc_get_product_variation_attributes($value);
                                        $variation_color=$attribute["attribute_".$selected_attr["color"]];
                                        $variation_size=$attribute["attribute_".$selected_attr["size"]];
                                            
                                        
                                        if($value!=$dflt_variation_id && !in_array($variation_color, $used_color_temp))
                                        {
                                            array_push($used_color_temp, $variation_color);

                                            if(empty($image_url))
                                            {
                                                ?>
                                                    <div class="atd-color-choice-item <?php if($key==0 && $product_id!=$dflt_product_id){echo "isActive"; }?>" atd-variation-id="<?= $value ?>" data-title="<?= $variation_color ?>" >
                                                        <img src="<?= wc_placeholder_img_src() ?>" alt="<?= __(get_the_title($value), 'atd') ?>" class="atd-preview-box-add-cart-img" data-src="<?= wc_placeholder_img_src() ?>" data-id="<?= $value ?>">
                                                    </div>
                                                <?php
                                            }
                                            else{
                                                ?>
                                                    <div class="atd-color-choice-item <?php if($key==0 && $product_id!=$dflt_product_id){echo "isActive"; }?>" atd-variation-id="<?= $value ?>" data-title="<?= $variation_color ?>">
                                                        <img src="<?= $image_url ?>" alt="<?= __(get_the_title($value), 'atd') ?>" class="atd-preview-box-add-cart-img" data-src="<?= $image_url ?>" data-id="<?= $value ?>" >
                                                    </div>
                                                <?php
                                            }
                                                
                                           
                                            $part_data_bg=$this->get_part_image($product_id, $value, "bg-inc");

                                            $part_data_icon=$this->get_part_image($product_id, $value, "icon");

                                            foreach ($part_data_bg as $xkey => $img_url){
                                                ?>
                                                    <span atd-variation-id="<?= $value ?>" data-title="<?= $xkey."_".$value ?>" style="display:none;">
                                                        <img src="<?= o_get_proper_image_url($img_url) ?>">
                                                    </span>
                                                <?php
                                            }
                                            
                                            foreach ($part_data_icon as $xkey => $img_url){
                                                ?>
                                                    <span atd-variation-id="<?= $value ?>" data-title="<?= "icon_".$xkey."_".$value ?>" style="display:none;">
                                                        <img src="<?= o_get_proper_image_url($img_url) ?>">
                                                    </span>
                                                <?php
                                            }
     
                                        }

                                    }
                                ?>

                        </div>

                        <div class="atd-add-product-notices">

                            <div class="atd-color-choice-item-notice">

                                <div class="atd-color-choice-item-notice-selected"></div>

                                <span class="atd-color-choice-item-notice-text"><?= __("Denotes a color already in your order.", "atd") ?></span>

                            </div>

                        </div>

                        <button type="button" <?php if($default){echo "disabled";} ?> class="atd-btn-product-add" data-own-id="<?= $dflt_variation_id ?>"><?= __('Add Product', 'atd') ?></button>

                    </div>
                    
                <?php
                
            }
            else
                echo $related_custom_product_details;
        }
        die();
    }

    /**
     * Récupère les informations sur la variarion par défaut
     * @param $_POST["product_id"]
     * @return array
     */

    public function get_default_product_variation_details(){
        if(isset($_POST["product_id"]))
        {
            $product_id=$_POST["product_id"];
            $details=atd_get_related_custom_product_details($product_id);
            array_push($details, get_the_title($product_id));
            echo json_encode($details);
            die();
        }
    }
    
    /**
     * Récupère l'url de l'image des parts 
     * @param $product_id, $variation_id, $image(bg-inc or icon)
     * @return array
     */
    public function get_part_image($product_id, $variation_id, $image){
        $meta_value= get_post_meta($product_id, "atd-metas", true);
        $part_data_arr=array(
            "Front" =>  $meta_value[$variation_id]["front"][$image],
            "Back"  =>  $meta_value[$variation_id]["back"][$image],
            "Left"  =>  $meta_value[$variation_id]["left"][$image],
            "Right" =>  $meta_value[$variation_id]["right"][$image],
            "Chest" =>  $meta_value[$variation_id]["chest"][$image],
        );

        return $part_data_arr;
    }

    /**
     * Get variation image url
     * @return  string 
     */

    public function get_variation_image_link($variation_id)
    {
        $variation = new WC_Product_Variation($variation_id);
        $img_id= $variation->get_image_id($variation_id);
        $image_url= wp_get_attachment_image_src($img_id, 'thumbnail');
        return $image_url[0];
    }


}
